

set pi [expr {4.0*atan(1.0)}]

set radsperdeg [expr {$pi/180.0}]

# 8/17/15 - wrong approach to solve for radius
#  should solve for tangent

proc r {theta} {
    global radsperdeg
    set rads [expr {$theta * $radsperdeg}]
    set s16 [expr {sin($rads)/16.0}]
    set r [expr {($s16 + sqrt( $s16 * $s16 + 1.0/32.0))/2.0}]
    return $r
    }
    
proc rc {theta} {
    global radsperdeg
    set rads [expr {$theta * $radsperdeg}]
    set r [expr {(3.0/32.0)/cos($rads)}]
    return $r
    }

# cutter Z above curve is computed as radius of curve a function of 
# rotation angle A
# The Z value (curve radius) when CNC rotating universal to angle A
# where A is 0 corresponds to the .125 Z value at top.
#  around A 90 and A270 the Z value is 3/32 
#
# CNC A is 0 when theta is 90
#     A is 90 when theta is 0
#   theta = 90 - A

# then going from A 90 to A 180 is theta 0 to 90
#     theta = abs ( 90 - A)

# for A > 180 r is like A - 180
proc rA {A} {  
    global radsperdeg
    if { $A > 180.0} {set A [expr {$A - 180}]}
    set theta [expr {abs(90.0 - $A)}]
    if { $theta < atan(1.0/3.0)/$radsperdeg} {
        return [rc $theta]
        }
     return [r $theta]
     }

#  Z of Tangent to Climax universal curve
# for rotary table angle A in degrees
# orientation:
#   A   zA
#   0   .12500
#   45  .11585
#   90  .09375
proc zA {A} {
    global radsperdeg ;# pi/180.0
    set rads [expr {$A * $radsperdeg}]
    # taking the absolute value of cos() 
    # is same as mapping angle A to 0 to 90
    set z [expr {3.0/32 + abs(cos($rads))/32.0}]
    set ztext [format "%.5f" $z]
    return $ztext
    }

# match illustrations which show -ve rotation (oops)
# stutter Y position in case feed motion ignores A moves
proc step1 {} {
    set ylist {0.005 -0.005}
    set index 0
    for {set a 0} {$a >= -90} {incr a -1} {
        set ztext [zA $a]
        puts "G1 A$a Z$ztext Y[lindex $ylist $index]"
        set index [expr 1 - $index]
        }
    }

proc step3 {} {
    set ylist {0.005 -0.005}
    set index 0
    for {set a -90} {$a >= -180} {incr a -1} {
        set ztext [zA $a]
        puts "G1 A$a Z$ztext Y[lindex $ylist $index]"
        set index [expr 1 - $index]
        }
    }

proc step4 {} {
    set ylist {0.005 -0.005}
    set index 1
    for {set a -181} {$a >= -360} {incr a -1} {
        set ztext [zA $a]
        puts "G1 A$a Z$ztext Y[lindex $ylist $index]"
        set index [expr 1 - $index]
        }
    }
# not getting cut depth on this side - fixture run-out? technique?
proc step4F {{mils 0.005}} {
    global radsperdeg ;# pi/180.0
    set ylist {0.005 -0.005}
    set index 1
    for {set a -181} {$a >= -360} {incr a -1} {
        set z [zA $a]
        set rads [expr {$a * $radsperdeg}]
        set factr [expr {sin($rads)*$mils}]
        set z [expr {$z - $factr}]
        set ztext [format "%.5f" $z]
        puts "G1 A$a Z$ztext Y[lindex $ylist $index]"
        set index [expr 1 - $index]
        }
    }

proc step4G {{var "#907"}} {
    global radsperdeg ;# pi/180.0
    set ylist {0.005 -0.005}
    set index 1
    for {set a -181} {$a >= -360} {incr a -1} {
        set ztext [zA $a]
        set rads [expr {$a * $radsperdeg}]
        set factr [format "%.5f" [expr {sin($rads)}]]
        puts "G1 A$a Z\[$ztext - $factr*$var\] Y[lindex $ylist $index]"
        set index [expr 1 - $index]
        }
    }

