#!/bin/sh
#      \
exec dmh_wish -f "$0" "$@"

#start dmh_wish -tclargs "proc start args {} ; proc goto args {} ; source claCylinderRound.bat"
#goto EndOfTcl

#  mill contour on motor cylinders

# hang off top right vise corner - back and forth in y
# z = 0 at top, x=0 along right edge, y= at vise (rear of part)
# vise clearance - cut of corner is about .175 inward


global R r Rplusr 
# R is curve radius
set R 0.3905
# r is cutter radius
set r 0.1875
set Rplusr [expr {$R + $r}]

# position of cutter lowest tip
proc z {theta} {
    global R r Rplusr 
    set z [expr {$Rplusr * (sin($theta) - 1.0)}]
    return $z
    }

# x position of cutter
proc x {theta} {
    global R r Rplusr 
    set x [expr {$Rplusr * cos($theta) - $R}]
    return $x
    }

# part is .91 y thick
set ymax 0.020
set ymin -.93
# start at theta of pi/2
set pi [expr 4.0*atan(1.0)]
set thetaMin 0.0
set thetaMax [expr {$pi/2.0}]
set thetaDiff $thetaMax
set xmin [x $thetaMax]

proc prolog {fid fname} {
    global xmin ymax
    puts $fid "(code from ${fname}.bat [::dmh::localtime 16])"
    puts $fid "(round off cylinder sticking out of vise right side)"
    puts $fid "( 0,0,0 is top right of part at vise rear edge, with 3/8 D ball end cutter)"
    puts $fid "( cutting starts at upper left corner xmin, ymax )"
    puts $fid "(--- typical prolog --)"
    puts $fid "G40 G80 G17 G90 G94"
    # puts $fid "(#904 = 9.2 set plunge rate)"
    puts $fid "#905 = 18.3 (set feed rate)"
    puts $fid "(T12 M06 G43 H12)"
    puts  $fid "S3056 M3"
    
    puts $fid [format "G0 X%.5f Y%.5f Z0.1" $xmin $ymax]
    puts $fid "G0 Z0.00200"
    puts $fid "G1 F#905 Z0.0 (plunge to set feed rate)"
    }

set debug 0
set fname "claCylinderRound"
if { $debug} {
    set fid stdout
    } else {
    set fid [open ${fname}.ngc w]
    }

prolog $fid $fname

set steps 50
set dir 0
for {set i $steps} {$i >= 0} {incr i -1} {
    set p [expr {double($i)/double($steps)}]
    set theta [expr {$thetaMin + $p * $thetaDiff}]
 if {$debug} {puts "p=$p theta = $theta"}
    set x [x $theta]
    set z [z $theta]
    if { $dir == 0} {
        # already at ymax
        puts $fid [format "G1 X%.5f Z%.5f" $x $z]
        puts $fid [format "G1 Y%.5f" $ymin]
     } else {
        # at ymin
        puts $fid [format "G1 X%.5f Z%.5f" $x $z]
        puts $fid [format "G1 Y%.5f" $ymax]
     }
     set dir [expr {1 - $dir}]
     }

puts $fid "(--- epilog ---)"
puts $fid "G0 Z4"
puts $fid "M30"
if { !$debug} {
    close $fid
    exit
    }
        
catch {console show}
proc s {} {
   global fname
   uplevel #0 source ${fname}.bat
   }


# \
:EndOfTcl 
