start dmh_wish -tclargs "proc start args {} ; proc goto args {} ; source claToolboxLid.bat"
goto EndOfTcl

# mill peaked roof of toolbox lid top
# z == 0 along top of roof peak
# sweep along x iterate over y
# start w .223 thick brass base is 1.485 wide in y, y=0 to y=1.485
# x one part is 1.391 wide ( +/- .6955) (add r+ for free motion lanes)
# x two part and .13 alley is  2.912 wide ( +/- 1.456) (add r+ for free motion lanes)

set zmax 0.0
# zmin not referenced
# you go lower off of the part to get the ball mill contact point low enough

# adding cutter r for free motion at ends - mill profile
#proc xmax {y} { return 1.456}
proc xmax {y} { return 1.644}
#proc xmin {y} { return -1.4546}
proc xmin {y} { return -1.644}


set pi [expr 4.0*atan(1.0)]
proc radians {deg} { return [expr {$::pi * $deg/180.0}]}

# steeper slope is thetaR 
# changeover pt at ypeak
# rear = rear of toolbox, lower y
set degRear 22.18
set thetaR [radians $degRear]
set ypeak .408
# front is front of toolbox, higher y
# higher y is gentler slope 
set degFront 8.54
set thetaF [radians $degFront]
# diameter cutter is 3/8
set rcutter [expr {3.0/16.0}]

# iterate over y +/- 0.003
set ymin -0.003
set ymax 1.488
#set ydiff [expr {$ymax - $ymin}]

# if iteration is at y, where is cutter y?
# cutter is moved away to be tanget to slope
# not worrying about beyond lid edge - there is another profiling cut to define extent
proc yc {y} {
    global thetaR ypeak thetaF zmax  rcutter
    if { $y < $ypeak } { # steeper lower y
        set yc [expr {$y - $rcutter * sin($thetaR)}]
     } elseif { $y > $ypeak } { # gentler
        set yc [expr {$y + $rcutter * sin($thetaF)}]
     } else {
        set yc $y
     }
     return $yc
     }

# at iteration position y, where is bottom tip of cutter, zc?
# start with z
proc zc {y} { 
    global thetaR ypeak thetaF zmax rcutter
    # z is top surface at y
    if {$y < $ypeak } { ;# rear heavy slope
        set zc [expr {$zmax - ($ypeak - $y) * tan($thetaR) - $rcutter * (1.0 - cos($thetaR))}]
    } elseif { $y > $ypeak} {
        set zc [expr {$zmax - ($y - $ypeak) * tan($thetaF) - $rcutter * (1.0 - cos($thetaF))}]
    } else { ;# along peak
        return $zmax
    }
    return $zc
    }
    


proc prolog {fid fname} {
    puts $fid "(code from ${fname}.bat [::dmh::localtime 16])"
    puts $fid "(toolbox lid top surface, z==0 at lid top)"
    puts $fid "(cutting back and forth along x axis)"
    puts $fid "(x = 0 at bisecting center of part)"
    puts $fid "(y = 0 at edge near operator, y=1.485 near vise rear)"
    puts $fid "(a profiling rectangular cut to define outside edges)"
    puts $fid "(of two toolbox lids is done in addition to this slope cutting)"
    puts $fid "( 3/8 Diameter ball end cutter)"
    puts $fid "( cutting starts at left peak xmin, ypeak )"
    puts $fid "(--- typical prolog --)"
    puts $fid "G40 G80 G17 G90 G94"
    # puts $fid "(#904 = 9.2 set plunge rate)"
    puts $fid "#905 = 18.3 (set feed rate)"
    puts $fid "(T12 M06 G43 H12)"
    puts  $fid "S3056 M3"
    
    puts $fid [format "G0 X%.5f Y%.5f Z0.1" [xmin $::ymin] [yc $::ypeak]]
    puts $fid "G0 Z0.00200"
    puts $fid "G1 F#905 Z0.0 (plunge to set feed rate)"
    }

set debug 0
set fname "claToolboxLid"
if { $debug} {
    set fid stdout
    } else {
    set fid [open ${fname}.ngc w]
    }

prolog $fid $fname

set steps 140
set dir 0
#for {set i $steps} {$i >= 0} {incr i -1} {}
for {set i 0} {$i <= $steps } {incr i} {
    set p [expr {double($i)/double($steps)}]
    if {$dir == 0} {
        # climb mill to right on rear, higher y side
        set yp [expr {$ypeak + $p * ($ymax - $ypeak)}]
        } else {
        # climb mill to left on operator side
        # this shorter side sees closer furrows
        set yp [expr {$ypeak - $p * ($ypeak - $ymin)}]
        }
    #set yp [expr {$ymin + $p * $ydiff}]
    set y [yc $yp]
    set z [zc $yp]

#puts "p=$p yp=$yp yc=$y zc=$z"
    # since we added +/- cutter r to ends, I am thinking we could
    # speedup with G0 positioning on the y z moves
    # but leaving it slow and safe in case user has not profiled the
    # rectangles
    if { $dir == 0} {
        # already at xmin
        puts $fid [format "G1 Y%.5f Z%.5f" $y $z]
        puts $fid [format "G1 X%.5f" [xmax $y]]
     } else {
        # at xmax
        puts $fid [format "G1 Y%.5f Z%.5f" $y $z]
        puts $fid [format "G1 X%.5f" [xmin $y]]
     }
     set dir [expr {1 - $dir}]
     }

puts $fid "(--- epilog ---)"
puts $fid "G0 Z4"
puts $fid "M2"
if { !$debug} {
    close $fid
    exit
    }
        
catch {console show}



# \
:EndOfTcl 
